# tmalibrary

Class files to be used during the development of `TMA Monitor` probes developed in `Python`.


## Prerequisites

To use this library, you need to install `requests` and `tmalibrary` module. To install these modules, you need to execute the following commands:

```sh
pip install requests
pip install tmalibrary
```

## Usage

To use this library in the development of your probe, you need to include the following lines in your probe main file, using the code below.

```python
from tmalibrary.probes import *
```